<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xpath-default-namespace="http://www.tei-c.org/ns/1.0"
    version="2.0">
    <!-- Achtung: TEI-Namensraum!
    Das Attribut xpath-default-namespace sagt, dass hier immer TEI als 
    Namensraum für die XPath-Ausdrücke angenommen werden soll -->
    
    <!-- Stylesheet, um aus den Weber-Briefen (briefkorpus-weber)
    eine Liste von Absende- und Empfängerorten zu extrahieren. 
    Die Liste soll auch wieder ein TEI-Dokument werden -->
    
    <!-- Hier kommt die XSL-Schablone, die auf das gesamte Eingabedokument
    angewandt wird (es "matcht" auf die Wurzel: /) -->
    <xsl:template match="/">
        <!-- Darin wird ein TEI-Dokument aufgebaut.
        Das soll in das Zieldokument geschrieben werden.
        Mit TEI-Header und TEI-Body. -->
        <TEI xmlns="http://www.tei-c.org/ns/1.0">
            <!-- Der TEI-Header wird direkt für das Zieldokuemnt
                geschrieben, ohne XSLT-Anweisungen 
                (weil hier nichts aus dem Eingabedokument geholt wird -->
            <teiHeader>
                <fileDesc>
                    <titleStmt>
                        <title>Ortsliste Carl Maria von Weber-Briefe</title>
                    </titleStmt>
                    <publicationStmt>
                        <p>unveröffentlicht</p>
                    </publicationStmt>
                    <sourceDesc>
                        <p>Extrahiert aus Briefen der Carl Maria von Weber-Gesamtausgabe</p>
                    </sourceDesc>
                </fileDesc>
            </teiHeader>
            <text>
                <body>
                    <!-- Hier wird ein TEI-Ortslisten-Element aufgemacht.
                    Danach kommen XSLT-Anweisungen, bevor das Element 
                    wieder geschlossen wird. -->
                    <listPlace>
                    <!-- Ab hier gibt es XSLT-Anweisungen:
                    In den TEI-Body soll die Ortsliste geschrieben werden -->
                    
                    <!-- Eine Variante von <xsl:for-each> ist <xsl:for-each-group>.
                    Damit werden Elemente gruppiert.
                    Es ist auch eine sogenannte "Schleife": Für jede Gruppe
                    soll innerhalb der for-each-group-Anweisung etwas getan werden.
                    
                    In @select wird mit XPath angesteuert, welche Elemente 
                    gruppiert werden sollen.
                    
                    Das sind hier alle Absende- und Empfängerorte aus der Sammlung
                    "briefcorpus-weber".
                    Dokumente aus einer Sammlung kann man mit der XPath-Funktion 
                    collection() auslesen.
                    Der vollständige XPath-Ausdruck zum Ansteuern der Ortselemente
                    lautet: collection('briefcorpus-weber')//correspAction/placeName
                    
                    @group-by gibt einen Gruppierungsschlüssel an.
                    Hier steht der Punkt (self: .), weil nach den Ortsnamen selbst,
                    die schon in @select ausgewählt wurden, gruppiert werden soll.
                    
                    Der Effekt des Gruppierens der Ortsnamen ist, dass alle
                    Ortsnamen, die gleich lauten, in derselben Gruppe landen.
                    Die Doppelungen fallen also raus, etwa wie bei der 
                    XPath-Funktion distinct-values(). Die kann man hier aber 
                    nicht so gut verwenden, weil mit jedem verschiedenen Ort 
                    noch etwas passieren soll: pro Ortsgruppe soll ein 
                    Registereintrag erstellt werden.
                    -->
                    <xsl:for-each-group select="collection('briefcorpus-weber')//correspAction/placeName" group-by=".">
                        <!-- Die Orte werden noch nach ihrem Namen 
                        alphabetisch sortiert. -->
                        <xsl:sort select="current-grouping-key()"/>
                        <!-- Jetzt beginnt das Erstellen des Registereintrags:
                        Die entsprechenden TEI-Elemente werden angelegt:
                        place = ein Ort
                        placeName = der Name des Ortes 
                        location = Lokalisierung des Ortes
                        geo = Geokoordinaten -->
                        <place>
                            <placeName>
                                <!-- Hier wird mit xsl:value-of der jeweils
                                aktuelle Gruppen-Ortsname rausgeschrieben.
                                Die Funktion current-grouping-key() gibt immer
                                den aktuellen Gruppenschlüssel zurück -->
                                <xsl:value-of select="current-grouping-key()"/>
                            </placeName>
                            <location>
                                <geo><!-- Die Geokoordinaten gibt es noch 
                                nicht. Die müssen hinterher in der 
                                vorbereiteten Liste ergänzt werden --></geo>
                            </location>
                        </place>
                        <!-- Dieser Teil wird für jede Gruppe (also jeden 
                        unterschiedlichen Ortsnamen) wiederholt (for-each!) -->
                    </xsl:for-each-group>
                    </listPlace>
                </body>
            </text>
        </TEI>
    </xsl:template>
    
    <!-- Es gibt hier keine weiteren Templates!
    Nur das Wurzeltemplate für die Ortsregister-Erstellung.
    Es sollen keine weiteren Unterelemente und kein Editionstext 
    ausgegeben werden.
    -->
    
    
</xsl:stylesheet>