<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    exclude-result-prefixes="xs" xpath-default-namespace="http://www.tei-c.org/ns/1.0"
    version="2.0">
    <!-- Achtung: die Eingabedokumente sind im TEI-Namensraum!
    Daher ist hier das Attribut xpath-default-namespace hinzugefügt -->
    
    <!-- Wurzeltemplate: die allgemeine Schablone als Ausgangspunkt -->
    <xsl:template match="/">
        <!-- Darin wird das Grundgerüst für das KML-Dokument konstruiert.
        Es wird erstmal direkt hineingeschrieben.
        Nach und nach werden die Elemente mit Inhalten aus den Briefdokumenten
        befüllt - mit Hilfe von XSLT-Anweisungen -->
        <kml xmlns="http://www.opengis.net/kml/2.2">
            <Document>
                <!-- Es wird EIN Gesamt-KML-Dokument erstellt; daher gibt es 
                EIN kml-Element und EIN Document-Element. -->
                
                <!-- Es sollen aber VIELE Placemark-Elemente erstellt werden:
                Für jeden Brief-Korrespondenzakt eines.
                Deshalb wird eine XSLT for-each-Schleife gebraucht! -->
                <xsl:for-each select="collection('briefcorpus-weber')//TEI">
                    <!-- Mit @select geht es hier hinein in das Briefkorpus.
                    Die XPath-Funktion collection() nimmt alle Dateien aus 
                    dem Ordern "briefcorpus-weber". Danach wird jeweils das
                    TEI-Wurzelelement angesprochen. -->
                    
                    <!-- für jeden Brief: neues Placemark-Element erstellen -->
                    <Placemark>
                        <!-- In das <name>-Element soll der Titel des 
                            Briefes hinein. -->
                        <name>
                            <xsl:value-of select="//title[@level='a']"/>
                        </name>
                        <!-- In <address> soll der Absendeort stehen. -->
                        <address>
                            <xsl:value-of select="//correspAction[@type='sent']/placeName"/>
                        </address>
                        <description>
                            <!-- In <description> sollen Informationen hinein, die 
                            den Brief näher beschreiben. Sie sollen im Geo-Browser
                            als HTML angezeigt werden.
                            Deshalb müssen die HTML-Elemente in CDATA-Blöcke, 
                            damit sie nicht versehentlich als zu transformierendes
                            XML verstanden werden. -->
                            <!-- Anfang CDATA-Block: -->
                            <xsl:text disable-output-escaping="yes">&lt;![CDATA[</xsl:text>
                            <p>Brief-ID:
                                <xsl:value-of select="@xml:id"/>
                            </p>
                            <p>Absender: 
                                <xsl:value-of select="//correspAction[@type='sent']/persName"/>
                            </p>
                            <p>Absendeort:
                                <xsl:value-of select="//correspAction[@type='sent']/placeName"/>
                            </p>
                            <p>Empfänger:
                                <xsl:value-of select="//correspAction[@type='received']/persName"/>
                            </p>
                            <p>Empfangsort:
                                <xsl:value-of select="//correspAction[@type='received']/placeName"/>
                            </p>
                            <p>Datum:
                                <xsl:value-of select="//correspAction[@type='sent']/date"/>
                            </p>
                            
                            <xsl:text disable-output-escaping="yes">]]&gt;</xsl:text>
                            <!-- Ende CDATA-Block -->
                        </description>
                        <!-- Nach der Beschreibung des Briefes wird die Zeitangabe für 
                        den Geo-Browser erstellt. 
                        Ein Element <TimeStamp>,
                        darin wird mit xsl:value-of das Absendedatum ausgegeben.
                        Man braucht das normierte Datum nach dem Format yyyy-mm-dd, 
                        welches in den TEI-Dateien in <correspAction> im
                        when-Attribut (oder @from - @to, oder @notBefore - @notAfter) steht. -->
                        <TimeStamp>
                            <!-- Das Absendedatum wird vorab in einer Variablen gespeichert.
                            Diese Variable wird danach wieder aufgerufen: $absendedatum,
                            wenn der Wert rausgeschrieben wird.
                            -->
                            <xsl:variable name="absendedatum">
                                <!-- innerhalb der Variablen wird das Datum herausgesucht -->
                                <!-- xsl:choose mit xsl:when: Wähle zwischen den verschiedenen
                                möglichen Fällen. Wenn der erste Fall in xsl:when zutrifft, 
                                wähle den aus. Trifft er nicht zu, teste den zweiten Fall.
                                Trifft er nicht zu, teste den dritten Fall, usw.
                                Wenn die Bedingung in @test stimmt, dann mache das, was innerhalb
                                von diesem <xsl:when> steht. 
                                Bei xsl:choose wird immer nur die erste zutreffende Variante 
                                abgearbeitet. -->
                                <xsl:choose>
                                    <xsl:when test="//correspAction[@type='sent']/date/@when">
                                        <xsl:value-of select="//correspAction[@type='sent']/date/@when"/>
                                    </xsl:when>
                                    <xsl:when test="//correspAction[@type='sent']/date/@from">
                                        <xsl:value-of select="//correspAction[@type='sent']/date/@from"/>
                                    </xsl:when>
                                    <xsl:when test="//correspAction[@type='sent']/date/@notBefore">
                                        <xsl:value-of select="//correspAction[@type='sent']/date/@notBefore"/>
                                    </xsl:when>
                                </xsl:choose>
                            </xsl:variable>
                            <!-- Hier wird das Absendedatum aus der Variablen rausgeschrieben. -->
                            <when><xsl:value-of select="$absendedatum"/></when>
                        </TimeStamp>
                        <!-- Schließlich kommen noch die Geokoordinaten: -->
                        <Point>
                            <coordinates>
                                <!-- Herausforderung: Die Koordinaten stehen
                                nicht in den Originalbriefen! 
                                Sie müssen aus der Ortsliste geholt werden,
                                welche in einem anderen TEI-Dokument mit dem 
                                Namen ortsliste.xml liegt. -->
                                <!-- Mit der XPath-Funktion document() kann man 
                                einzelne XML-Dokumente innerhalb des XSLT-Stylesheets
                                dazuladen. -->
                                
                                <!-- Der aktuelle Absendeort des Briefes muss also abgeglichen
                                werden mit den Ortsnamen in der Ortsliste.
                                In der Ortsliste stehen die Geokoordinaten, die sollen für 
                                den aktuellen Ort herausgesucht werden. -->
                                
                                <!-- Erstmal den aktuellen Absendeort in einer XSLT-Variablen ablegen: -->
                                <xsl:variable name="Absendeort" select="//correspAction[@type='sent']/placeName"/>
                                <!-- Dann das andere Dokument öffnen und den Ortsnamen heraussuchen,
                                der dem aktuellen Ort entspricht.
                                Den auch wieder in einer Variablen zwischenspeichern. -->
                                <xsl:variable name="Ort-Register" select="document('ortsliste.xml')//place[placeName=$Absendeort]"/>
                                <!-- KML erwartet: erst Längengrad,
                                    dann Komma,
                                    dann Breitengrad -->
                                <!-- Längen- und Breitengrad aus der Registerdatei heraussuchen
                                und in Variablen zwischenspeichern -->
                                <xsl:variable name="Längengrad" select="substring-after($Ort-Register/location/geo,' ')"/>
                                <xsl:variable name="Breitengrad" select="substring-before($Ort-Register/location/geo,' ')"/>
                                <!-- Längen- und Breitengrad rausschreiben -->
                                <xsl:value-of select="concat($Längengrad,',',$Breitengrad)"/>
                            </coordinates>
                        </Point>
                    </Placemark>
                </xsl:for-each>
                <!-- Die Schleife geht wieder zu: Danach sind alle TEI-Dokumente,
                also jeder einzelne Brief abgearbeitet. Für jeden wurde ein 
                <Placemark>-Element erstellt. -->
            </Document>
        </kml>
        <!-- Hier wird auch das umgebende kml-Element wieder geschlossen -->
    </xsl:template>
    <!-- Ende der XSLT-Schablone -->
    
</xsl:stylesheet>